--------------------------------------------------------
# goda: Python library to work with government open data

## What is it?

Description...

## Main Features
 
Description...

## Where to get it
Description...

## Dependencies

- [pandas](https://pandas.pydata.org/index.html)
- [geopandas](geopandas)

## License

[BSD 3](https://github.com/Charles-Darwing-Data-Community/goda/blob/master/LICENSE)
